/*---------------------------------------------------------------------------*\
  =========                 |
  \\      /  F ield         | OpenFOAM: The Open Source CFD Toolbox
   \\    /   O peration     |
    \\  /    A nd           | Copyright (C) 1991-2010 OpenCFD Ltd.
     \\/     M anipulation  |
-------------------------------------------------------------------------------
License
    This file is part of OpenFOAM.

    OpenFOAM is free software: you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    OpenFOAM is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    for more details.

    You should have received a copy of the GNU General Public License
    along with OpenFOAM.  If not, see <http://www.gnu.org/licenses/>.

\*---------------------------------------------------------------------------*/

#include <reactionThermophysicalModels/chemkinReader.H>
#include <OpenFOAM/argList.H>
#include <OpenFOAM/IFstream.H>
#include <OpenFOAM/OFstream.H>

using namespace Foam;

// * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * //
// Main program:

int main(int argc, char *argv[])
{
    argList::validArgs.clear();
    argList::validArgs.append("CHEMKINIIIFile");
    argList::validOptions.insert("thermo", "fileName");
    argList args(argc, argv);

    fileName thermoFileName = fileName::null;
    if (args.options().found("thermo"))
    {
        thermoFileName = args.options()["thermo"];
    }

    fileName CHEMKINFileName(args.additionalArgs()[0]);

    chemkinReader ck(CHEMKINFileName, thermoFileName);

    //Info<< ck.isotopeAtomicWts() << endl;
    //Info<< ck.specieNames() << endl;
    //Info<< ck.speciePhase() << endl;
    //Info<< ck.specieThermo() << endl;
    //Info<< ck.reactions() << endl;

    const SLPtrList<gasReaction>& reactions = ck.reactions();

    {
        OFstream reactionStream("reactions");
        reactionStream<< reactions << endl;
    }

    {
        IFstream reactionStream("reactions");

        label nReactions(readLabel(reactionStream));
        reactionStream.readBeginList(args.executable().c_str());

        PtrList<gasReaction> testReactions(nReactions);

        forAll (testReactions, i)
        {
            testReactions.set
            (
                i,
                gasReaction::New
                (
                    ck.species(),
                    ck.speciesThermo(),
                    reactionStream
                )
            );
        }

        reactionStream.readEndList(args.executable().c_str());

        Info<< testReactions << endl;
    }

    Info << "End\n" << endl;

    return 0;
}


// ************************ vim: set sw=4 sts=4 et: ************************ //
